#!/bin/ksh
# scriptDb.sh

ORACLE_SID=$1
a=`hostname`
PSDBA="xxxxxx"

# OS Definition
myPID=$$

# Files
sqlFile="<PathTo>/scriptDb.sql"
sqlplusOutputLog="/tmp/schema_${myPID}.log"

# Sleep time in seconds
maxSleepTime=300 # Max sleep time, after, the SQL script will be killed
loopSleepTime=5  # Each loop will sleep it
countLoopSleetTime=0

# Start SQLPlus in background
# The @, means, START the SQL script after it and give the log file as argument
# The log file is the SPOOL in the SQL script
nohup sqlplus -L @"${sqlFile}" "${sqlplusOutputLog}" 1>/dev/null 2>&1 &

# Loop while true
# To stop the loop, an error will need to be found in the SQL script log file
# Or the maximum sleep time is passed
while true
do
	if [ ${countLoopSleetTime} -ge ${maxSleepTime} ]
	then
		pid=`ps -ef | egrep "${sqlFile}" | awk '{print $2}'`
		# You can change the following to: kill -9 ${pid}
		kill -15 ${pid}
		break
	fi
	
	chk_err=`egrep -i 'ORA-|SP2-|TNS-|Usage' "${sqlplusOutputLog}" | wc -l`
	if [ ${chk_err} -ne 0 ]
	then
		break
	fi
	
	sleep ${loopSleepTime}
	countLoopSleetTime=`expr ${countLoopSleetTime} + ${loopSleepTime}`
done

# Sends an e-mail if some problem is found
chk_err=`egrep -i 'ORA-|SP2-|TNS-|Usage' "${sqlplusOutputLog}" | wc -l`
if [ $chk_err -ne 0 ]
then
	mailx -s "USER Stats gather failed on instance ${ORACLE_SID} on host ${a}" $PSDBA < "${sqlplusOutputLog}"
fi

exit 0